#
# spec file for package linuxptp
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
Name:           linuxptp
Version:        1.8+git65.g303b08c
Release:        lp150.1.2
Summary:        Precision Time Protocol v2 daemon
License:        GPL-2.0+
Group:          Productivity/Networking/Other
URL:            http://linuxptp.sourceforge.net/
Source0:        %{name}-%{version}.tar.xz
Source1:        ptp4l.service
Source2:        sysconfig.ptp4l
Source3:        linuxptp.firewall
Source4:        linuxptp-howto.txt
Source5:        phc2sys.service
Source6:        sysconfig.phc2sys
BuildRequires:  kernel-devel
BuildRequires:  systemd-rpm-macros
Requires(pre):  %fillup_prereq
Provides:       ptp-timekeeping
%{?systemd_requires}

%description
This software is an implementation of the Precision Time Protocol (PTP)
according to the IEEE1588 standard for Linux.

%prep
%setup -q

%build
export EXTRA_CFLAGS="%{optflags} -Iusr/include"
make %{?_smp_mflags}

cp %{SOURCE4} .

%install
make prefix=%{buildroot}%{_prefix} mandir=%{buildroot}/%{_mandir} install

install -Dpm 644 %{SOURCE1} %{buildroot}/%{_unitdir}/ptp4l.service
install -Dpm 644 %{SOURCE5} %{buildroot}/%{_unitdir}/phc2sys.service
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcptp4l
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcphc2sys

install -Dpm 644 default.cfg %{buildroot}/%{_sysconfdir}/ptp4l.conf

install -Dpm 644 %{SOURCE2} %{buildroot}%{_fillupdir}/sysconfig.ptp4l
install -Dpm 644 %{SOURCE6} %{buildroot}%{_fillupdir}/sysconfig.phc2sys

install -Dpm 644 %{SOURCE3} %{buildroot}/%{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/linuxptp

%pre
%service_add_pre ptp4l.service phc2sys.service

%post
%{fillup_only -n ptp4l}
%{fillup_only -n phc2sys}
%service_add_post ptp4l.service phc2sys.service

%preun
%service_del_preun ptp4l.service phc2sys.service

%postun
%service_del_postun ptp4l.service phc2sys.service

%files
%doc README.org COPYING linuxptp-howto.txt
%{_unitdir}/ptp4l.service
%{_unitdir}/phc2sys.service
%{_sbindir}/rcptp4l
%{_sbindir}/rcphc2sys
%config %{_sysconfdir}/ptp4l.conf
%config %{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/linuxptp
%{_sbindir}/hwstamp_ctl
%{_sbindir}/phc2sys
%{_sbindir}/phc_ctl
%{_sbindir}/pmc
%{_sbindir}/ptp4l
%{_sbindir}/timemaster
%{_mandir}/man8/hwstamp_ctl.8%{ext_man}
%{_mandir}/man8/phc2sys.8%{ext_man}
%{_mandir}/man8/phc_ctl.8%{ext_man}
%{_mandir}/man8/pmc.8%{ext_man}
%{_mandir}/man8/ptp4l.8%{ext_man}
%{_mandir}/man8/timemaster.8%{ext_man}
%{_fillupdir}/sysconfig.ptp4l
%{_fillupdir}/sysconfig.phc2sys

%changelog
* Thu Feb  8 2018 jbohac@suse.com
- change the versioning scheme, resulting in version
  1.8+git65.g303b08c
* Thu Feb  8 2018 mpluskal@suse.com
- Update to version v1.8+git.20180101 (bsc#1050682):
  * clock: Don't forward management requests to UDS port.
  * Add an acknowledgment in the readme for Meinberg.
  * phc2sys: update '-s' option
  * sk: don't leak socket when reading of IB GUID fails.
  * Add compile time sanity check for interface name lengths.
  * phc_ctl: fix adj command to accept negative offset.
  * port: return timestamping iface in port properties
  * phc2sys: re-create clock clkid and servo when phc index changed
  * phc2sys: split servo_add from function clock_add
  * transport: pass struct interface to transport_open
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Mon Jul 10 2017 jengelh@inai.de
- Remove future goals from description.
* Fri Jun 30 2017 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Use url for source
- Use kernel-devel instead full source
* Thu May 25 2017 lpechacek@suse.com
- upgraded to 1.8
- new tools: timemaster, phc_ctl
* Tue Sep  2 2014 ro@suse.de
- sanitize release line in specfile
* Thu Mar 27 2014 lpechacek@suse.com
- updated How To to mention ethtool (bnc#865358)
* Wed Mar 26 2014 jbohac@suse.cz
- convert to systemd (bnc#865355)
  - two separate services (ptp4l and phc2sys) instead of linuxptp
  - two separate config files:
    /etc/syscconfig/ptp4l and /etc/sysconfig/phc2sys instead of
    /etc/sysconfig/linuxptp
* Tue Feb 18 2014 jbohac@suse.cz
- upgraded to 1.4
- fixed FSF address in init file
* Fri Jul 26 2013 lpechacek@suse.com
- added Linux PTP Howto
* Thu Jun  6 2013 lpechacek@suse.com
- adjusted sysconfig defaults to match changes made to phc2sys
  behavior
* Wed Jun  5 2013 jbohac@suse.cz
- upgraded to 1.2.git74e70372
* Tue Apr 23 2013 jbohac@suse.cz
- upgraded to 1.2
* Mon Mar 25 2013 lpechacek@suse.com
- reviewed by Security (bnc#809336)
* Fri Mar 15 2013 cfarrell@suse.com
- license update: GPL-2.0+
  No indication of a GPL version 2 only license. Also, use SPDX format
  where possible
* Wed Mar  6 2013 lpechacek@suse.com
- upgraded to 1.1
* Fri Feb 15 2013 lpechacek@suse.com
- initial packaging
